%Import, organize, and plot frequency distributions for rain
%drop-size and velocity data for the irrigation system on LEO-E.  Raw data
%were collected by Jon Pelletier.

%The difference between this file and the one completed on 3/5 is that here
%I omit the velocity bins greater than 7 m/s and the drop size bins greater
%than 3 mm, since these bins always had counts of 0.

%Luke Pangle, 3/26/2014

clear all;
close all;
clc;

i=input('Import Data (type 1 for yes, 0 for no): ');

if i==1;
    %Import file information for all 60 files.
    files=dir('*.xls');
    x=importdata('spectrum11.xls');
    vbins=x.colheaders(1:15);                   %bins of velocity values (m/s)
    dsbins=x.data(1:11,22);                        %bins of drop-size values (mm)

    %This loop creates two 24x21x60 arrays.  Each layer of the third dimension
    %(i.e. 1-60) corresponds to a specific .xls file, and therefore a specific
    %trial with the disdrometer.  One array contains absolute values; the other
    %contains values that are normalized by the sum.
    data=zeros(11,15,length(files));
    data_norm=zeros(11,15,length(files));
    for i=1:length(files);
        x=importdata(files(i).name);
        data(1:11,1:15,i)=x.data(1:11,1:15);
        sum1=sum(x.data);                                               %calculate sum of all columns in 2-d array. This will include the last column, which is actually the bins of drop sizes (not data).
        data_norm(1:11,1:15,i)=x.data(1:11,1:15)/sum(sum1(1:21));          %normalize each data point in the array by the sum of the array. Sum only includes columns 1-21, as column 22 is bin categories.
        sum2=sum(data_norm(1:11,1:15,i));
        sum3(i)=sum(sum2(:));
        if sum3 ~= 1;
            sprintf('Sum of counts does not equal 1 for iteration %d',i)
        end
    end
    save('data.mat');
    save('data_norm.mat');

else
    load('data.mat');
    load('data_norm.mat');
end

%Separate the test# and replicate# from the filename.
idnum=zeros(length(files),1);
for i=1:length(files);
    idnum(i)=sscanf(files(i).name,'spectrum%f.xls');
end

%Separate the test# from the replicate#
idnum_s=num2str(idnum);
testnum=zeros(length(idnum),1);
repnum=zeros(length(idnum),1);
for i=1:length(idnum_s);
    if isempty(str2num(idnum_s(i,1)))==1;
        testnum(i)=str2num(idnum_s(i,2));
        repnum(i)=str2num(idnum_s(i,3));
    else
        testnum(i)=str2num(idnum_s(i,1:2));
        repnum(i)=str2num(idnum_s(i,3));
    end
end

%From the preceding: the row # in the vectors "testnum" and "repnum"
%corresponds to the value of the third dimension in data arrays "data" and
%"data_norm".  These "testnum" values correspond to individual tests (i.e.
%individual irrigation circuits, and from the bottom or top of the slope),
%and the "repnum" values correspond to the replicate number of that test (5
%replicates/test).

%create 6 plots, each a 2x1 array, and each one showing a bar graph with 10 series: the five
%replicate tests conducted with that irrigation circuit at both the upslope
%and downslope positions (5 reps x 2 locations = 10 tests).
vbins=str2double(vbins);
for i=1:6;                              
    j=i+6;                              
    grpi=find(testnum==i|testnum==j);                   %find all matrices associated with a particular circuit, should be length of 10 every time (i.e. 1 circuit x 2 locations x 5 replicates/location)
    grp=data_norm(:,:,grpi);                            %a 24x21x10 array, where 24 is the number of drop-size bins, 21 is the number of drop-velocity bins, and 10 is the number of replicate trials for each circuit (including those measured at the downslope and upslope positions).
    grp2=data(:,:,grpi);
    for n=1:length(grpi);                               %loop through every layer of the 3-d array, where each layer is a specific test for a specific irrigation circuit.
        for p=1:length(dsbins);                         %within each layer loop through every row (where the row is associated with a particular bin of drop sizes)
            dsgrptot(p,n)=sum(grp(p,:,n));              %calculate the total count for that drop size (i.e. row) within that layer (i.e. replicate).  creates a matrix with number of rows equal to the number of drop-size bins, and number of columns equal to the number of layers (i.e. replicate tests)
            dsgrptot2(p,n)=sum(grp2(p,:,n));
        end
        for q=1:length(vbins);
            dvgrptot(q,n)=sum(grp(:,q,n));
            dvgrptot2(q,n)=sum(grp2(:,q,n));
        end
    end
    figure(i);
    subplot(2,1,1);
    bar(dsbins,dsgrptot);
    legend('rep1','rep2','rep3','rep4','rep5','rep6','rep7','rep8','rep9','rep10');
    xlabel('drop-size (mm)');
    ylabel('frequency');
    ylim([0 0.4]);
    xlim([0 5]);
    str=sprintf('Circuit %d',i);
    title(str);
    
    subplot(2,1,2);
    bar(vbins,dvgrptot);
    xlabel('drop velocity (m/s)');
    ylabel('frequency');
    ylim([0 0.4]);
    xlim([0 11]);
    
    %Create 6 additional plots that show boxplots for drop size and drop
    %velocity, where data from all 10 trials for each irrigation circuit
    %are lumped together.
    dscirtot=sum(dsgrptot2(:));                             %calculate the sum of all count data from all 10 tests for the particular circuit
    dsboxvar=zeros(dscirtot,1);                             %create a vector of zeros with length equal to that sum
    for k=1:length(dsbins);
        rowsums=(sum(dsgrptot2(k,:)));                      %the sum, across all 10 tests, of counts for a given drop size
        a=1;                                                %a temporary index value
        dsboxvar(a:rowsums)=dsbins(k);                      %in the vector "dsboxvar", make the first number of entried (number = rowsums) equal to the drop-size associated with "rowsum".  This is filling the variable dsboxvar with the appropriate number of occurrences of that drop size for a box plot below.
        a=a+rowsums;                                        %modify the index for the next loop
    end
    dvcirtot=sum(dvgrptot2(:));
    dvboxvar=zeros(dvcirtot,1);
    for l=1:length(vbins);
        rowsums=(sum(dvgrptot2(l,:)));
        a=1;
        dvboxvar(a:rowsums)=vbins(l);
        a=a+rowsums;
    end
        
    figure(i+6);
    subplot(1,2,1);
    b=find(dsboxvar>0); boxplot(dsboxvar(b));
    ylabel('drop size (mm)');
    ylim([0 5]);
    set(gca,'XTickLabel',[]);
    str=sprintf('Circuit %d',i);
    title(str);
    
    subplot(1,2,2);
    b=find(dvboxvar>0); boxplot(dvboxvar(b));
    ylabel('drop velocity (m/s)');
    ylim([0 11]);
    set(gca,'XTickLabel',[]);
    title(str);
    
end

%create 6 plots: each plot is a 3-d bar graph showing the combined
%frequency distributions of drop size and drop velocity for each irrigation
%circuit, and for all circuits combined.
format long;
for i=1:6;                              
    j=i+6;                              
    grpi=find(testnum==i|testnum==j);                   %find all matrices associated with a particular circuit, should be length of 10 every time (i.e. 1 circuit x 2 locations x 5 replicates/location)
    grp=data(:,:,grpi);                                 %a 3-d array with data from a particular circuit
    for n=1:length(dsbins);                             %loop through every row (i.e. every bin of drop size)
        for p=1:length(vbins);                          %loop through every column (i.e. every bin of drop velocity)
            cirtot(n,p)=sum(grp(n,p,:));                %calculate the average of all count values for specific combinations of drop size and drop velocity for a particular circuit
            cirtot_norm(n,p)=cirtot(n,p)/sum(grp(:));
        end
    end
    
    figure(i+12);
    bar3(cirtot_norm,'b');
    set(gca,'XTick',1:21,'YTick',1:24,'XTickLabel',vbins,'YTickLabel',dsbins);
    xlabel('drop velocity (m/s)');
    set(gca,'fontsize',8);
    ylabel('drop size (mm)');
    zlabel('frequency');
    zlim([0 0.08]);
    str=sprintf('Circuit %d',i);
    title(str);
    
    %Create 6 additional plots showing the same data, but with 2-d
    %colormaps.
    figure(i+18);
    pcolor(cirtot_norm);
    colormap(jet(18));
    caxis([0 0.09]);
    colorbar;
    set(gca,'XTick',1:21,'YTick',1:24,'XTickLabel',vbins,'YTickLabel',dsbins);
    xlabel('drop velocity (m/s)');
    ylabel('drop size (mm)');
    set(gca,'fontsize',8);
    str=sprintf('Circuit %d',i);
    title(str);
end

%create a figure for the LEO site description paper

%terminal drop sizes and drop velocities provided by Jon Pelletier; based
%on empirical equations from Dietrich, 1982, WRR.
termds=[0.125 0.25 0.375 0.5 0.75 1 1.25 1.5 1.75 2 2.5 3 3.5 4];
termdv=[0.32 0.84 1.38 1.92 2.9 3.79 4.58 5.3 5.95 6.55 7.62 8.55 9.38 10.11];
for i=1:6;                              
    j=i+6;
    evod=rem(i,2)==0;
    grpi=find(testnum==i|testnum==j);                   %find all matrices associated with a particular circuit, should be length of 10 every time (i.e. 1 circuit x 2 locations x 5 replicates/location)
    grp=data(:,:,grpi);                                 %a 3-d array with data from a particular circuit
    for n=1:length(dsbins);                             %loop through every row (i.e. every bin of drop size)
        for p=1:length(vbins);                          %loop through every column (i.e. every bin of drop velocity)
            cirtot(n,p)=sum(grp(n,p,:));                %calculate the average of all count values for specific combinations of drop size and drop velocity for a particular circuit
            cirtot_norm(n,p)=cirtot(n,p)/sum(grp(:));
        end
    end
    if i<6;
        figure(25);
        subplot(3,2,i);
        pcolor(cirtot_norm);
        colormap(jet(18));
        caxis([0 0.09]);
        colorbar;
        set(gca,'XTick',1:21,'YTick',1:24,'XTickLabel',vbins,'YTickLabel',dsbins);
        xlabel('drop velocity (m/s)');
        if evod==0;
            ylabel('drop size (mm)');
        else
            set(gca,'YTickLabel',[]);
        end
        set(gca,'fontsize',10);
        str=sprintf('Circuit %d',i);
        title(str);
    else
        subplot(3,2,i);
        plot(termdv,termds);
        xlabel('drop velocity (m/s)');
        ylabel('drop size (mm)');
        set(gca,'XLim',[0 6],'XTick',1:6,'YTick',[0:0.25:2],'YGrid','on','fontsize',10);
    end
end

